ManifestParser

Trait ManifestParser 

pub trait ManifestParser {
    // Required methods
    fn manifest_name(&self) -> &str;
    fn can_parse(&self, manifest_path: &Path) -> bool;
    fn parse(
        &self,
        manifest_path: &Path,
        workspace_root: &Path,
    ) -> Result<(Project, Vec<Dependency>), KdoError>;
}
Trait implemented by each language-specific manifest parser.

Required Methods

fn manifest_name(&self) -> &str

Returns the canonical manifest filename (e.g., Cargo.toml).

fn can_parse(&self, manifest_path: &Path) -> bool

Check whether this parser can handle the given manifest path.

fn parse( &self, manifest_path: &Path, workspace_root: &Path, ) -> Result<(Project, Vec<Dependency>), KdoError>

Parse a manifest file, returning a project and its declared dependencies.

workspace_root is used to resolve relative path dependencies.

Implementors